##  Step 1: Create a Custom Attribute for Energy Consumption on IT Component Fact Sheets
Follow these steps:
  1. On the user profile, select Administration, and then select Meta Model Configuration in the sidebar.
  2. On the Meta Model Configuration page, select the IT component fact sheet. You land on the fact sheet configuration page.
  3. In the subsection where you want to place the custom attribute, click Add field. If needed, create a new section with a subsection.
  4. In the sidebar, specify the attribute details:
     * In the Key field, enter a unique key that serves as the attribute identifier, such as EnergyConsumptionLevel.
     * In the Type list, select Integer.
     * Specify other attribute details and click Create.
     * On the tab indicated by the globe icon, enter translations for the attribute label to the target languages.
  5. In the sidebar, click Show changes, and then click Apply.


The custom attribute for energy consumption values is added to IT component fact sheets.
